![CI](https://github.com/DavidCouronne/latextomd/workflows/CI/badge.svg)

# latextomd

A simple python package to convert latex to markdown (katex)

Documentation: https://latextomd.netlify.com/

## Installation

```bash
pip install latextomd
```

## Basic usage

```bash
latextomd -i source.tex -o export.md
```

# Requirements (Windows 10)

+ miktex
+ pandoc
+ perl: [http://strawberryperl.com/](http://strawberryperl.com/)

```{bash}
choco install berrybrew
```

+ Image Magick: [https://imagemagick.org/](https://imagemagick.org/)

```{bash}
choco install imagemagick
```

